"""
confirmemail feature configuration.

Auto-generated by `splent feature:inject-config`.
Injects environment variables into Flask app.config.
"""

import os


def inject_config(app):
    app.config.update({
        "CONFIRM_EMAIL_SALT": os.getenv("CONFIRM_EMAIL_SALT", "sample_salt"),
        "CONFIRM_EMAIL_TOKEN_MAX_AGE": int(os.getenv("CONFIRM_EMAIL_TOKEN_MAX_AGE", "3600")),
    })



from splent_framework.hooks.template_hooks import register_template_hook
from flask import url_for


def confirmemail_scripts():
    return '<script src="' + url_for('confirmemail.assets', subfolder='dist', filename='splent_feature_confirmemail.bundle.js') + '"></script>'


register_template_hook("layout.scripts", confirmemail_scripts)
